@@ -38,7 +38,7 @@ def fsarray(strings, *args, **kwargs):
     if 'width' in kwargs:
         width = kwargs['width']
         del kwargs['width']
-        if max(len(s) for s in strings) > width:
+        if strings and max(len(s) for s in strings) > width:
             raise ValueError("Those strings won't fit for width %d" % width)
     else:
         width = max(len(s) for s in strings) if strings else 0
